/*
 * Component: utils
 *
 * Description:
 *         A simplier interface for adding/removing references from C/C++ programs.
 *
 *
 * Last Updated     : $Author$
 * Update Date Time : $Date$
 * RCS File Name    : $RCSfile$
 * RCS Revision     : $Revision$
 * Locked by        : $Locker$
 * Symbolic name    : $Name$
 * State            : $State$
 */

#ifndef IM_REF_COUNT_H_INCLUDED
#define IM_REF_COUNT_H_INCLUDED

#include "ReferenceCounter.h"

/**
 * A simplier interface for adding/removing references from C/C++ programs.
 *
 * addReference() and removeReference() methods will load the reference counter file, add/remove the reference
 * and then release the reference counter file.
 *
 * Both methods will catch exceptions, and returns error (if applicable) in such cases.
 *
 * It's worth to keep a static RefCount object in the memory and use it to manipulate reference counters.
 */
class RefCount {
	// Release configuration for the reference counters
	ReleaseConfig m_releaseConfig;

	// Verbose mode for printing verbose messages
	bool m_verbose;

public:

	/**
	 * Constructor for creating a new RefCount object. It will load the release configuration file.
	 *
	 * @param verbose   verbose messages will be printed on standard output if true
	 */
	RefCount(bool verbose = false);
	
	/**
	 * Adds a reference to a reference counter file
	 *
	 * @param referenceType   type of the reference counter file
	 * @param refcountId      identifies the reference counter file
	 * @param reference       reference to be added
	 *
	 * @return true if and only if the reference was successfully added to the reference counter file
	 */
	bool addReference(const char * referenceType, const char * refcountId, const char * reference);


	/**
	 * Removes a reference to a reference counter file
	 *
	 * @param referenceType   type of the reference counter file
	 * @param refcountId      identifies the reference counter file
	 * @param reference       reference to be added
	 */
	void removeReference(const char * referenceType, const char * refcountId, const char * reference);
};

#endif // IM_REF_COUNT_H_INCLUDED
